<template>
  <div style="display: flex; flex-wrap: wrap; justify-content: center; margin-bottom: 20px">
    <div class=wrap v-for="(value, key) in bedMap" :key="key">
      <RoomStatus :title="key" :bedList="value"  @refresh="getList"/>
    </div>
  </div>
  <el-button @click="startBiz"> 手动开诊 </el-button>
  <el-button @click="resetRoom"> 重置诊室 </el-button>
  <el-button @click="resetSchedule"> 重置定时任务 </el-button>
  <el-button @click="refresh"> 刷新 </el-button>
</template>

<script setup lang="ts">
import {RoomStatus} from "@/components/RoomStatus"
import { RoomApi, RoomVO } from '@/api/ecg/room'
import { QueueApi } from '@/api/ecg/queue'

defineOptions({ name: 'RoomStatusSetting' })

const bedMap = ref() // 列表的数据

/** 查询列表 */
const getList = async () => {
    const data = await RoomApi.getAllBedMap()
    bedMap.value = data as Map<String, RoomVO[]>
}

const startBiz = async () => {
  await QueueApi.startBiz();
}

const resetRoom = async () => {
  await RoomApi.resetRoom();
  getList()
}

const resetSchedule = async () => {
  await QueueApi.resetSchedule();
}

const refresh = async () => {
  getList()
}

/** 初始化 **/
onMounted(() => {
    getList()
})

</script>

<style scoped lang="scss">
.wrap {
  margin-right: 20px;
}
</style>
